==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/so-SO/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Ku saabsan Goobaha',
    'about_locations'           => 'Goobaha waxaa loo isticmaalaa si loola socdo macluumaadka goobta isticmaalayaasha, hantida, iyo walxaha kale',
    'assets_rtd'                => 'Hantida', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Hantida loo qoondeeyay',
    'id'                        => 'Aqoonsi',
    'city'                      => 'Magaalada',
    'state'                     => 'Gobolka',
    'country'                   => 'Dalka',
    'create'                    => 'Samee Goobta',
    'update'                    => 'Cusbooneysii Goobta',
    'print_assigned'            => 'Daabacaadda loo qoondeeyay',
    'print_all_assigned'        => 'Daabac Dhammaan Ku-meel-gaadhka ah',
    'name'                      => 'Magaca Goobta',
    'address'                   => 'Cinwaanka',
    'address2'                   => 'Khadka Ciwaanka 2',
    'zip'                       => 'Koodhka Boostada',
    'locations'                 => 'Goobaha',
    'parent'                    => 'Waalid',
    'currency'                  => 'Lacagta Goobta',
    'ldap_ou'                   => 'Raadi LDAP',
    'user_name'                 => 'Magaca isticmaalaha',
    'department'                => 'Waaxda',
    'location'                  => 'Goobta',
    'asset_tag'                 => 'Hantida Tag',
    'asset_name'                => 'Magaca',
    'asset_category'            => 'Qaybta',
    'asset_manufacturer'        => 'Soo saaraha',
    'asset_model'               => 'Qaabka',
    'asset_serial'              => 'Taxane',
    'asset_location'            => 'Goobta',
    'asset_checked_out'         => 'La Hubiyay',
    'asset_expected_checkin'    => 'Hubinta la filayo',
    'date'                      => 'Taariikhda:',
    'phone'                     => 'Magaca Goobta',
    'signed_by_asset_auditor'   => 'Waxa saxeexay (Hantidhawraha Hantida):',
    'signed_by_finance_auditor' => 'Waxa saxeexay (Hantidhawraha Maaliyadda):',
    'signed_by_location_manager' => 'Waxa saxeexay (Maamulaha Goobta):',
    'signed_by'                 => 'Saxiixay:',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/so-SO/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Ku saabsan Goobaha',
    'about_locations'           => 'Goobaha waxaa loo isticmaalaa si loola socdo macluumaadka goobta isticmaalayaasha, hantida, iyo walxaha kale',
    'assets_rtd'                => 'Hantida', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Hantida la qoondeeyay',
    'id'                        => 'Aqoonsi',
    'city'                      => 'Magaalada',
    'state'                     => 'Gobolka',
    'country'                   => 'Dalka',
    'create'                    => 'Samee Goobta',
    'update'                    => 'Cusbooneysii Goobta',
    'print_assigned'            => 'Daabacaadda la qoondeeyay',
    'print_all_assigned'        => 'Daabac Dhammaan kuwa la qoondeeyay',
    'name'                      => 'Magaca Goobta',
    'address'                   => 'Cinwaanka',
    'address2'                   => 'Khadka Ciwaanka 2',
    'zip'                       => 'Koodhka Boostada',
    'locations'                 => 'Goobaha',
    'parent'                    => 'Waalid',
    'currency'                  => 'Lacagta Goobta',
    'ldap_ou'                   => 'LDAP raadinaya OU',
    'user_name'                 => 'Magaca isticmaalaha',
    'department'                => 'Waaxda',
    'location'                  => 'Goobta',
    'asset_tag'                 => 'Hantida calaamadeysan',
    'asset_name'                => 'Magaca',
    'asset_category'            => 'Qaybta',
    'asset_manufacturer'        => 'Soo saaraha',
    'asset_model'               => 'Qaabka',
    'asset_serial'              => 'Taxane',
    'asset_location'            => 'Goobta',
    'asset_checked_out'         => 'La Hubiyay',
    'asset_expected_checkin'    => 'Hubinta la filayo',
    'date'                      => 'Taariikhda:',
    'phone'                     => 'Teleefanka goobta',
    'signed_by_asset_auditor'   => 'Waxaa saxiixay (Hantidhawraha guud):',
    'signed_by_finance_auditor' => 'Waxaa saxiixay (Hantidhawraha Maaliyadda):',
    'signed_by_location_manager' => 'Waxaa saxiixay (Maamulaha Goobta):',
    'signed_by'                 => 'Saxiixay:',
];
